
# Slot: vital_status


living or dead status

URI: [nwb_schema_language:vital_status](https://w3id.org/p2p_ld/nwb-schema-language/vital_status)


## Domain and Range

None &#8594;  <sub>0..1</sub> [PersonStatus](PersonStatus.md)

## Parents


## Children


## Used by

 * [Namespaces](Namespaces.md)
